@@ -14,7 +14,7 @@
 #include <QStringView>
 
 XmltvFetcher::XmltvFetcher()
-    : m_doc("xmltv")
+    : m_doc(QStringLiteral("xmltv"))
 {
     m_provider.get(QUrl::fromLocalFile(TellySkoutSettings::xmltvFile()), std::bind(&XmltvFetcher::open, this, std::placeholders::_1), [](const Error &error) {
         Q_UNUSED(error)
@@ -38,7 +38,7 @@ void XmltvFetcher::fetchGroups(std::function<void(const QVector<GroupData> &)> c
     QVector<GroupData> groups;
 
     GroupData data;
-    data.m_id = GroupId("xmltv");
+    data.m_id = GroupId(QStringLiteral("xmltv"));
     data.m_name = i18n("XMLTV");
     data.m_url = TellySkoutSettings::xmltvFile();
 
@@ -60,16 +60,16 @@ void XmltvFetcher::fetchGroup(const QString &url,
 
     QMap<ChannelId, ChannelData> channels;
 
-    QDomNodeList nodes = m_doc.elementsByTagName("channel");
+    QDomNodeList nodes = m_doc.elementsByTagName(QStringLiteral("channel"));
 
     for (int i = 0; i < nodes.count(); i++) {
         QDomNode elm = nodes.at(i);
         if (elm.isElement()) {
             const QDomNamedNodeMap &attributes = elm.attributes();
-            const ChannelId id = ChannelId(attributes.namedItem("id").toAttr().value());
+            const ChannelId id = ChannelId(attributes.namedItem(QStringLiteral("id")).toAttr().value());
 
-            const QString &name = elm.firstChildElement("display-name").text();
-            const QString &icon = elm.firstChildElement("icon").attributes().namedItem("src").toAttr().value();
+            const QString &name = elm.firstChildElement(QStringLiteral("display-name")).text();
+            const QString &icon = elm.firstChildElement(QStringLiteral("icon")).attributes().namedItem(QStringLiteral("src")).toAttr().value();
 
             fetchChannel(id, name, icon, channels);
         }
@@ -88,12 +88,12 @@ void XmltvFetcher::fetchProgram(const ChannelId &channelId,
 
     QVector<ProgramData> programs;
 
-    QDomNodeList programNodes = m_doc.elementsByTagName("programme");
+    QDomNodeList programNodes = m_doc.elementsByTagName(QStringLiteral("programme"));
     for (int i = 0; i < programNodes.count(); i++) {
         const QDomNode &program = programNodes.at(i);
         const QDomNamedNodeMap &attributes = program.attributes();
 
-        if (channelId.value() != attributes.namedItem("channel").toAttr().value()) {
+        if (channelId.value() != attributes.namedItem(QStringLiteral("channel")).toAttr().value()) {
             continue; // TODO: do not loop all programs for each channel
         }
         programs.push_back(processProgram(program));
@@ -125,13 +125,13 @@ QString XmltvFetcher::image(const QString &url, std::function<void()> callback,
     Q_UNUSED(callback)
     Q_UNUSED(errorCallback)
 
-    return "";
+    return QStringLiteral("");
 }
 
 QString XmltvFetcher::imagePath(const QString &url)
 {
     Q_UNUSED(url);
-    return "";
+    return QStringLiteral("");
 }
 
 void XmltvFetcher::open(QByteArray data)
@@ -150,7 +150,7 @@ void XmltvFetcher::fetchChannel(const ChannelId &channelId, const QString &name,
         ChannelData data;
         data.m_id = channelId;
         data.m_name = name;
-        data.m_url = "";
+        data.m_url = QStringLiteral("");
         data.m_image = icon;
 
         channels.insert(channelId, data);
@@ -162,27 +162,27 @@ ProgramData XmltvFetcher::processProgram(const QDomNode &program)
     ProgramData data;
 
     const QDomNamedNodeMap &attributes = program.attributes();
-    data.m_channelId = ChannelId(attributes.namedItem("channel").toAttr().value());
-    const QString &startTimeString = attributes.namedItem("start").toAttr().value();
-    QDateTime startTime = QDateTime::fromString(startTimeString.left(14), "yyyyMMddHHmmss");
+    data.m_channelId = ChannelId(attributes.namedItem(QStringLiteral("channel")).toAttr().value());
+    const QString &startTimeString = attributes.namedItem(QStringLiteral("start")).toAttr().value();
+    QDateTime startTime = QDateTime::fromString(startTimeString.left(14), QStringLiteral("yyyyMMddHHmmss"));
     const int startTimeOffset = QStringView{startTimeString}.right(5).left(3).toInt();
     startTime.setOffsetFromUtc(startTimeOffset * 3600);
     startTime = startTime.toUTC();
     data.m_startTime = startTime;
     // channel + start time can be used as ID
-    data.m_id = ProgramId(data.m_channelId.value() + "_" + QString::number(startTime.toSecsSinceEpoch()));
-    const QString &stopTimeString = attributes.namedItem("stop").toAttr().value();
-    QDateTime stopTime = QDateTime::fromString(stopTimeString.left(14), "yyyyMMddHHmmss");
+    data.m_id = ProgramId(data.m_channelId.value() + QStringLiteral("_") + QString::number(startTime.toSecsSinceEpoch()));
+    const QString &stopTimeString = attributes.namedItem(QStringLiteral("stop")).toAttr().value();
+    QDateTime stopTime = QDateTime::fromString(stopTimeString.left(14), QStringLiteral("yyyyMMddHHmmss"));
     const int stopTimeOffset = QStringView{stopTimeString}.right(5).left(3).toInt();
     stopTime.setOffsetFromUtc(stopTimeOffset * 3600);
     stopTime = stopTime.toUTC();
     data.m_stopTime = stopTime;
-    data.m_title = program.namedItem("title").toElement().text();
-    data.m_subtitle = program.namedItem("sub-title").toElement().text();
-    data.m_description = program.namedItem("desc").toElement().text();
+    data.m_title = program.namedItem(QStringLiteral("title")).toElement().text();
+    data.m_subtitle = program.namedItem(QStringLiteral("sub-title")).toElement().text();
+    data.m_description = program.namedItem(QStringLiteral("desc")).toElement().text();
 
     if (program.isElement()) {
-        QDomNodeList categoryNodes = program.toElement().elementsByTagName("category");
+        QDomNodeList categoryNodes = program.toElement().elementsByTagName(QStringLiteral("category"));
         for (int i = 0; i < categoryNodes.count(); i++) {
             data.m_categories.push_back(categoryNodes.at(i).toElement().text());
         }
